@@ -13,7 +13,6 @@
 import time
 
 from oslo_log import log as logging
-import six
 from tempest import config
 from tempest.lib import decorators
 from tempest.lib import exceptions
@@ -69,8 +68,8 @@ class ShareShrinkBase(manager.ShareScenarioTest):
 
         LOG.debug('Step 4 - grant access')
         location = self.get_user_export_locations(share)[0]
-        self.allow_access(instance=instance, remote_client=remote_client,
-                          locations=location)
+        self.allow_access(share=share, instance=instance,
+                          remote_client=remote_client, locations=location)
 
         LOG.debug('Step 5 - mount')
         self.mount_share(location, remote_client)
@@ -80,7 +79,7 @@ class ShareShrinkBase(manager.ShareScenarioTest):
         LOG.debug('Step 6 - writing {} * 64MB blocks'.format(blocks))
         self.write_data_to_mounted_share_using_dd(remote_client,
                                                   '/mnt/t1', '64M',
-                                                  blocks, '/dev/urandom')
+                                                  blocks)
         ls_result = remote_client.exec_command("sudo ls -lAh /mnt/")
         LOG.debug(ls_result)
 
@@ -91,11 +90,12 @@ class ShareShrinkBase(manager.ShareScenarioTest):
             self.shares_v2_client, share['id'],
             ['shrinking_possible_data_loss_error', 'available'])
 
-        share = self.shares_v2_client.get_share(share["id"])
+        share = self.shares_v2_client.get_share(share["id"])['share']
 
         if share["status"] == constants.STATUS_AVAILABLE:
             params = {'resource_id': share['id']}
-            messages = self.shares_v2_client.list_messages(params=params)
+            messages = self.shares_v2_client.list_messages(
+                params=params)['messages']
             self.assertIn('009',
                           [message['action_id'] for message in messages])
             self.assertEqual(share_size, int(share["size"]))
@@ -113,14 +113,14 @@ class ShareShrinkBase(manager.ShareScenarioTest):
         self.share_shrink_retry_until_success(share["id"],
                                               new_size=default_share_size)
 
-        share = self.shares_v2_client.get_share(share["id"])
+        share = self.shares_v2_client.get_share(share["id"])['share']
         self.assertEqual(default_share_size, int(share["size"]))
 
         LOG.debug('Step 11 - write more data than allocated, should fail')
         self.assertRaises(
             exceptions.SSHExecCommandFailed,
             self.write_data_to_mounted_share_using_dd,
-            remote_client, '/mnt/t1', '64M', blocks, '/dev/urandom')
+            remote_client, '/mnt/t1', '64M', blocks)
 
         LOG.debug('Step 12 - unmount')
         self.unmount_share(remote_client)
@@ -130,7 +130,7 @@ class ShareShrinkBase(manager.ShareScenarioTest):
         """Try share reset, followed by shrink, until timeout"""
 
         check_interval = CONF.share.build_interval * 2
-        share = self.shares_v2_client.get_share(share_id)
+        share = self.shares_v2_client.get_share(share_id)['share']
         share_current_size = share["size"]
         share_status = share[status_attr]
         start = int(time.time())
@@ -145,11 +145,11 @@ class ShareShrinkBase(manager.ShareScenarioTest):
                                                        new_size=new_size)
                 except exceptions.BadRequest as e:
                     if ('New size for shrink must be less than current size'
-                            in six.text_type(e)):
+                            in str(e)):
                         break
 
             time.sleep(check_interval)
-            share = self.shares_v2_client.get_share(share_id)
+            share = self.shares_v2_client.get_share(share_id)['share']
             share_status = share[status_attr]
             share_current_size = share["size"]
             if share_current_size == new_size:
